summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEric Bruneton <ebruneton@free.fr>2022-10-01 15:33:07 +0000
committerEric Bruneton <ebruneton@free.fr>2022-10-01 15:33:07 +0000
commite21d96e6131c7dde99b9986ef64a08e4d25980e8 (patch)
treedd721ff3c4c4eb5313f2b57c187fa305da876277
parent965c0069c2ed9818c2ee91469ec3ef0e8534c36b (diff)
downloadow2-asm-e21d96e6131c7dde99b9986ef64a08e4d25980e8.tar.gz
Add link to Type.getInternalName() after each occurence of 'internal name' in...
-rw-r--r--asm-analysis/src/main/java/org/objectweb/asm/tree/analysis/Analyzer.java12
-rw-r--r--asm-commons/src/main/java/org/objectweb/asm/commons/AnalyzerAdapter.java20
-rw-r--r--asm-commons/src/main/java/org/objectweb/asm/commons/AnnotationRemapper.java2
-rw-r--r--asm-commons/src/main/java/org/objectweb/asm/commons/GeneratorAdapter.java5
-rw-r--r--asm-commons/src/main/java/org/objectweb/asm/commons/InstructionAdapter.java9
-rw-r--r--asm-commons/src/main/java/org/objectweb/asm/commons/JSRInlinerAdapter.java6
-rw-r--r--asm-commons/src/main/java/org/objectweb/asm/commons/Remapper.java37
-rw-r--r--asm-commons/src/main/java/org/objectweb/asm/commons/SimpleRemapper.java5
-rw-r--r--asm-tree/src/main/java/org/objectweb/asm/tree/ClassNode.java26
-rw-r--r--asm-tree/src/main/java/org/objectweb/asm/tree/FieldInsnNode.java4
-rw-r--r--asm-tree/src/main/java/org/objectweb/asm/tree/ModuleExportNode.java8
-rw-r--r--asm-tree/src/main/java/org/objectweb/asm/tree/ModuleNode.java18
-rw-r--r--asm-tree/src/main/java/org/objectweb/asm/tree/ModuleOpenNode.java7
-rw-r--r--asm-tree/src/main/java/org/objectweb/asm/tree/ModuleProvideNode.java9
-rw-r--r--asm-tree/src/main/java/org/objectweb/asm/tree/TryCatchBlockNode.java5
-rw-r--r--asm-tree/src/main/java/org/objectweb/asm/tree/TypeInsnNode.java6
-rw-r--r--asm-util/src/main/java/org/objectweb/asm/util/Printer.java131
-rw-r--r--asm-util/src/main/java/org/objectweb/asm/util/Textifier.java7
-rw-r--r--asm/src/main/java/org/objectweb/asm/ClassReader.java2
-rw-r--r--asm/src/main/java/org/objectweb/asm/ClassTooLargeException.java5
-rw-r--r--asm/src/main/java/org/objectweb/asm/ClassVisitor.java11
-rw-r--r--asm/src/main/java/org/objectweb/asm/ClassWriter.java20
-rw-r--r--asm/src/main/java/org/objectweb/asm/Handle.java7
-rw-r--r--asm/src/main/java/org/objectweb/asm/MethodTooLargeException.java4
-rw-r--r--asm/src/main/java/org/objectweb/asm/MethodVisitor.java13
-rw-r--r--asm/src/main/java/org/objectweb/asm/ModuleVisitor.java17
-rw-r--r--asm/src/main/java/org/objectweb/asm/Type.java2
-rw-r--r--asm/src/main/java/org/objectweb/asm/signature/SignatureVisitor.java3
28 files changed, 231 insertions, 170 deletions
diff --git a/asm-analysis/src/main/java/org/objectweb/asm/tree/analysis/Analyzer.java b/asm-analysis/src/main/java/org/objectweb/asm/tree/analysis/Analyzer.java
index 7aad8db5..40432a5b 100644
--- a/asm-analysis/src/main/java/org/objectweb/asm/tree/analysis/Analyzer.java
+++ b/asm-analysis/src/main/java/org/objectweb/asm/tree/analysis/Analyzer.java
@@ -92,7 +92,8 @@ public class Analyzer<V extends Value> implements Opcodes {
/**
* Analyzes the given method.
*
- * @param owner the internal name of the class to which 'method' belongs.
+ * @param owner the internal name of the class to which 'method' belongs (see {@link
+ * Type#getInternalName()}).
* @param method the method to be analyzed. The maxStack and maxLocals fields must have correct
* values.
* @return the symbolic state of the execution stack frame at each bytecode instruction of the
@@ -280,7 +281,8 @@ public class Analyzer<V extends Value> implements Opcodes {
* Analyzes the given method and computes and sets its maximum stack size and maximum number of
* local variables.
*
- * @param owner the internal name of the class to which 'method' belongs.
+ * @param owner the internal name of the class to which 'method' belongs (see {@link
+ * Type#getInternalName()}).
* @param method the method to be analyzed.
* @return the symbolic state of the execution stack frame at each bytecode instruction of the
* method. The size of the returned array is equal to the number of instructions (and labels)
@@ -468,7 +470,8 @@ public class Analyzer<V extends Value> implements Opcodes {
/**
* Computes the initial execution stack frame of the given method.
*
- * @param owner the internal name of the class to which 'method' belongs.
+ * @param owner the internal name of the class to which 'method' belongs (see {@link
+ * Type#getInternalName()}).
* @param method the method to be analyzed.
* @return the initial execution stack frame of the 'method'.
*/
@@ -527,7 +530,8 @@ public class Analyzer<V extends Value> implements Opcodes {
* Initializes this analyzer. This method is called just before the execution of control flow
* analysis loop in {@link #analyze}. The default implementation of this method does nothing.
*
- * @param owner the internal name of the class to which the method belongs.
+ * @param owner the internal name of the class to which the method belongs (see {@link
+ * Type#getInternalName()}).
* @param method the method to be analyzed.
* @throws AnalyzerException if a problem occurs.
*/
diff --git a/asm-commons/src/main/java/org/objectweb/asm/commons/AnalyzerAdapter.java b/asm-commons/src/main/java/org/objectweb/asm/commons/AnalyzerAdapter.java
index 1a6d12d8..c31533ec 100644
--- a/asm-commons/src/main/java/org/objectweb/asm/commons/AnalyzerAdapter.java
+++ b/asm-commons/src/main/java/org/objectweb/asm/commons/AnalyzerAdapter.java
@@ -60,9 +60,10 @@ public class AnalyzerAdapter extends MethodVisitor {
* {@link Opcodes#TOP}, {@link Opcodes#INTEGER}, {@link Opcodes#FLOAT}, {@link Opcodes#LONG},
* {@link Opcodes#DOUBLE},{@link Opcodes#NULL} or {@link Opcodes#UNINITIALIZED_THIS} (long and
* double are represented by two elements, the second one being TOP). Reference types are
- * represented by String objects (representing internal names), and uninitialized types by Label
- * objects (this label designates the NEW instruction that created this uninitialized value). This
- * field is {@literal null} for unreachable instructions.
+ * represented by String objects (representing internal names, see {@link
+ * Type#getInternalName()}), and uninitialized types by Label objects (this label designates the
+ * NEW instruction that created this uninitialized value). This field is {@literal null} for
+ * unreachable instructions.
*/
public List<Object> locals;
@@ -71,9 +72,10 @@ public class AnalyzerAdapter extends MethodVisitor {
* {@link Opcodes#TOP}, {@link Opcodes#INTEGER}, {@link Opcodes#FLOAT}, {@link Opcodes#LONG},
* {@link Opcodes#DOUBLE},{@link Opcodes#NULL} or {@link Opcodes#UNINITIALIZED_THIS} (long and
* double are represented by two elements, the second one being TOP). Reference types are
- * represented by String objects (representing internal names), and uninitialized types by Label
- * objects (this label designates the NEW instruction that created this uninitialized value). This
- * field is {@literal null} for unreachable instructions.
+ * represented by String objects (representing internal names, see {@link
+ * Type#getInternalName()}), and uninitialized types by Label objects (this label designates the
+ * NEW instruction that created this uninitialized value). This field is {@literal null} for
+ * unreachable instructions.
*/
public List<Object> stack;
@@ -82,9 +84,9 @@ public class AnalyzerAdapter extends MethodVisitor {
/**
* The uninitialized types in the current execution frame. This map associates internal names to
- * Label objects. Each label designates a NEW instruction that created the currently uninitialized
- * types, and the associated internal name represents the NEW operand, i.e. the final, initialized
- * type value.
+ * Label objects (see {@link Type#getInternalName()}). Each label designates a NEW instruction
+ * that created the currently uninitialized types, and the associated internal name represents the
+ * NEW operand, i.e. the final, initialized type value.
*/
public Map<Object, Object> uninitializedTypes;
diff --git a/asm-commons/src/main/java/org/objectweb/asm/commons/AnnotationRemapper.java b/asm-commons/src/main/java/org/objectweb/asm/commons/AnnotationRemapper.java
index af1305cb..3eeaf0f6 100644
--- a/asm-commons/src/main/java/org/objectweb/asm/commons/AnnotationRemapper.java
+++ b/asm-commons/src/main/java/org/objectweb/asm/commons/AnnotationRemapper.java
@@ -196,7 +196,7 @@ public class AnnotationRemapper extends AnnotationVisitor {
/**
* Maps an annotation attribute name with the remapper. Returns the original name unchanged if the
- * internal name of the annotation is {@literal null}.
+ * descriptor of the annotation is {@literal null}.
*
* @param name the name of the annotation attribute.
* @return the new name of the annotation attribute.
diff --git a/asm-commons/src/main/java/org/objectweb/asm/commons/GeneratorAdapter.java b/asm-commons/src/main/java/org/objectweb/asm/commons/GeneratorAdapter.java
index 874a381f..97f832b1 100644
--- a/asm-commons/src/main/java/org/objectweb/asm/commons/GeneratorAdapter.java
+++ b/asm-commons/src/main/java/org/objectweb/asm/commons/GeneratorAdapter.java
@@ -276,7 +276,7 @@ public class GeneratorAdapter extends LocalVariablesSorter {
* Returns the internal names of the given types.
*
* @param types a set of types.
- * @return the internal names of the given types.
+ * @return the internal names of the given types (see {@link Type#getInternalName()}).
*/
private static String[] getInternalNames(final Type[] types) {
String[] names = new String[types.length];
@@ -1354,7 +1354,8 @@ public class GeneratorAdapter extends LocalVariablesSorter {
*
* @param start beginning of the exception handler's scope (inclusive).
* @param end end of the exception handler's scope (exclusive).
- * @param exception internal name of the type of exceptions handled by the handler.
+ * @param exception internal name of the type of exceptions handled by the handler (see {@link
+ * Type#getInternalName()}).
*/
public void catchException(final Label start, final Label end, final Type exception) {
Label catchLabel = new Label();
diff --git a/asm-commons/src/main/java/org/objectweb/asm/commons/InstructionAdapter.java b/asm-commons/src/main/java/org/objectweb/asm/commons/InstructionAdapter.java
index 1e85cf79..afe8d689 100644
--- a/asm-commons/src/main/java/org/objectweb/asm/commons/InstructionAdapter.java
+++ b/asm-commons/src/main/java/org/objectweb/asm/commons/InstructionAdapter.java
@@ -1063,7 +1063,8 @@ public class InstructionAdapter extends MethodVisitor {
/**
* Deprecated.
*
- * @param owner the internal name of the method's owner class.
+ * @param owner the internal name of the method's owner class (see {@link
+ * Type#getInternalName()}).
* @param name the method's name.
* @param descriptor the method's descriptor (see {@link Type}).
* @deprecated use {@link #invokevirtual(String, String, String, boolean)} instead.
@@ -1101,7 +1102,8 @@ public class InstructionAdapter extends MethodVisitor {
/**
* Deprecated.
*
- * @param owner the internal name of the method's owner class.
+ * @param owner the internal name of the method's owner class (see {@link
+ * Type#getInternalName()}).
* @param name the method's name.
* @param descriptor the method's descriptor (see {@link Type}).
* @deprecated use {@link #invokespecial(String, String, String, boolean)} instead.
@@ -1139,7 +1141,8 @@ public class InstructionAdapter extends MethodVisitor {
/**
* Deprecated.
*
- * @param owner the internal name of the method's owner class.
+ * @param owner the internal name of the method's owner class (see {@link
+ * Type#getInternalName()}).
* @param name the method's name.
* @param descriptor the method's descriptor (see {@link Type}).
* @deprecated use {@link #invokestatic(String, String, String, boolean)} instead.
diff --git a/asm-commons/src/main/java/org/objectweb/asm/commons/JSRInlinerAdapter.java b/asm-commons/src/main/java/org/objectweb/asm/commons/JSRInlinerAdapter.java
index e96de73f..e1beedfc 100644
--- a/asm-commons/src/main/java/org/objectweb/asm/commons/JSRInlinerAdapter.java
+++ b/asm-commons/src/main/java/org/objectweb/asm/commons/JSRInlinerAdapter.java
@@ -88,7 +88,8 @@ public class JSRInlinerAdapter extends MethodNode implements Opcodes {
* @param name the method's name.
* @param descriptor the method's descriptor.
* @param signature the method's signature. May be {@literal null}.
- * @param exceptions the internal names of the method's exception classes. May be {@literal null}.
+ * @param exceptions the internal names of the method's exception classes (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
* @throws IllegalStateException if a subclass calls this constructor.
*/
public JSRInlinerAdapter(
@@ -123,7 +124,8 @@ public class JSRInlinerAdapter extends MethodNode implements Opcodes {
* @param name the method's name.
* @param descriptor the method's descriptor.
* @param signature the method's signature. May be {@literal null}.
- * @param exceptions the internal names of the method's exception classes. May be {@literal null}.
+ * @param exceptions the internal names of the method's exception classes (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
*/
protected JSRInlinerAdapter(
final int api,
diff --git a/asm-commons/src/main/java/org/objectweb/asm/commons/Remapper.java b/asm-commons/src/main/java/org/objectweb/asm/commons/Remapper.java
index 414edcec..dc046f8c 100644
--- a/asm-commons/src/main/java/org/objectweb/asm/commons/Remapper.java
+++ b/asm-commons/src/main/java/org/objectweb/asm/commons/Remapper.java
@@ -49,7 +49,7 @@ public abstract class Remapper {
* @param descriptor a type descriptor.
* @return the given descriptor, with its [array element type] internal name remapped with {@link
* #map(String)} (if the descriptor corresponds to an array or object type, otherwise the
- * descriptor is returned as is).
+ * descriptor is returned as is). See {@link Type#getInternalName()}.
*/
public String mapDesc(final String descriptor) {
return mapType(Type.getType(descriptor)).getDescriptor();
@@ -63,7 +63,7 @@ public abstract class Remapper {
* @return the given type, with its [array element type] internal name remapped with {@link
* #map(String)} (if the type is an array or object type, otherwise the type is returned as
* is) or, of the type is a method type, with its descriptor remapped with {@link
- * #mapMethodDesc(String)}.
+ * #mapMethodDesc(String)}. See {@link Type#getInternalName()}.
*/
private Type mapType(final Type type) {
switch (type.getSort()) {
@@ -87,8 +87,10 @@ public abstract class Remapper {
/**
* Returns the given internal name, remapped with {@link #map(String)}.
*
- * @param internalName the internal name (or array type descriptor) of some (array) class.
- * @return the given internal name, remapped with {@link #map(String)}.
+ * @param internalName the internal name (or array type descriptor) of some (array) class (see
+ * {@link Type#getInternalName()}).
+ * @return the given internal name, remapped with {@link #map(String)} (see {@link
+ * Type#getInternalName()}).
*/
public String mapType(final String internalName) {
if (internalName == null) {
@@ -100,8 +102,10 @@ public abstract class Remapper {
/**
* Returns the given internal names, remapped with {@link #map(String)}.
*
- * @param internalNames the internal names (or array type descriptors) of some (array) classes.
- * @return the given internal name, remapped with {@link #map(String)}.
+ * @param internalNames the internal names (or array type descriptors) of some (array) classes
+ * (see {@link Type#getInternalName()}).
+ * @return the given internal name, remapped with {@link #map(String)} (see {@link
+ * Type#getInternalName()}).
*/
public String[] mapTypes(final String[] internalNames) {
String[] remappedInternalNames = null;
@@ -255,9 +259,11 @@ public abstract class Remapper {
* strategy that will work for inner classes produced by Java, but not necessarily other
* languages. Subclasses can override.
*
- * @param name the fully-qualified internal name of the inner class.
- * @param ownerName the internal name of the owner class of the inner class.
- * @param innerName the internal name of the inner class.
+ * @param name the fully-qualified internal name of the inner class (see {@link
+ * Type#getInternalName()}).
+ * @param ownerName the internal name of the owner class of the inner class (see {@link
+ * Type#getInternalName()}).
+ * @param innerName the internal name of the inner class (see {@link Type#getInternalName()}).
* @return the new inner name of the inner class.
*/
public String mapInnerClassName(
@@ -279,7 +285,8 @@ public abstract class Remapper {
* Maps a method name to its new name. The default implementation of this method returns the given
* name, unchanged. Subclasses can override.
*
- * @param owner the internal name of the owner class of the method.
+ * @param owner the internal name of the owner class of the method (see {@link
+ * Type#getInternalName()}).
* @param name the name of the method.
* @param descriptor the descriptor of the method.
* @return the new name of the method.
@@ -304,7 +311,8 @@ public abstract class Remapper {
* Maps a record component name to its new name. The default implementation of this method returns
* the given name, unchanged. Subclasses can override.
*
- * @param owner the internal name of the owner class of the field.
+ * @param owner the internal name of the owner class of the field (see {@link
+ * Type#getInternalName()}).
* @param name the name of the field.
* @param descriptor the descriptor of the field.
* @return the new name of the field.
@@ -318,7 +326,8 @@ public abstract class Remapper {
* Maps a field name to its new name. The default implementation of this method returns the given
* name, unchanged. Subclasses can override.
*
- * @param owner the internal name of the owner class of the field.
+ * @param owner the internal name of the owner class of the field (see {@link
+ * Type#getInternalName()}).
* @param name the name of the field.
* @param descriptor the descriptor of the field.
* @return the new name of the field.
@@ -353,8 +362,8 @@ public abstract class Remapper {
* Maps the internal name of a class to its new name. The default implementation of this method
* returns the given name, unchanged. Subclasses can override.
*
- * @param internalName the internal name of a class.
- * @return the new internal name.
+ * @param internalName the internal name of a class (see {@link Type#getInternalName()}).
+ * @return the new internal name (see {@link Type#getInternalName()}).
*/
public String map(final String internalName) {
return internalName;
diff --git a/asm-commons/src/main/java/org/objectweb/asm/commons/SimpleRemapper.java b/asm-commons/src/main/java/org/objectweb/asm/commons/SimpleRemapper.java
index 9986f10d..6803d948 100644
--- a/asm-commons/src/main/java/org/objectweb/asm/commons/SimpleRemapper.java
+++ b/asm-commons/src/main/java/org/objectweb/asm/commons/SimpleRemapper.java
@@ -54,7 +54,7 @@ public class SimpleRemapper extends Remapper {
* attribute (in the form &lt;owner&gt;.&lt;name&gt;), and the value is the new field
* name.
* <li>for internal names, the key is the old internal name, and the value is the new
- * internal name.
+ * internal name (see {@link org.objectweb.asm.Type#getInternalName()}).
* </ul>
*/
public SimpleRemapper(final Map<String, String> mapping) {
@@ -66,7 +66,8 @@ public class SimpleRemapper extends Remapper {
*
* @param oldName the key corresponding to a method, field or internal name (see {@link
* #SimpleRemapper(Map)} for the format of these keys).
- * @param newName the new method, field or internal name.
+ * @param newName the new method, field or internal name (see {@link
+ * org.objectweb.asm.Type#getInternalName()}).
*/
public SimpleRemapper(final String oldName, final String newName) {
this.mapping = Collections.singletonMap(oldName, newName);
diff --git a/asm-tree/src/main/java/org/objectweb/asm/tree/ClassNode.java b/asm-tree/src/main/java/org/objectweb/asm/tree/ClassNode.java
index a9f362c1..bd43dc71 100644
--- a/asm-tree/src/main/java/org/objectweb/asm/tree/ClassNode.java
+++ b/asm-tree/src/main/java/org/objectweb/asm/tree/ClassNode.java
@@ -58,14 +58,14 @@ public class ClassNode extends ClassVisitor {
*/
public int access;
- /** The internal name of this class (see {@link org.objectweb.asm.Type#getInternalName}). */
+ /** The internal name of this class (see {@link org.objectweb.asm.Type#getInternalName()}). */
public String name;
/** The signature of this class. May be {@literal null}. */
public String signature;
/**
- * The internal of name of the super class (see {@link org.objectweb.asm.Type#getInternalName}).
+ * The internal of name of the super class (see {@link org.objectweb.asm.Type#getInternalName()}).
* For interfaces, the super class is {@link Object}. May be {@literal null}, but only for the
* {@link Object} class.
*/
@@ -73,7 +73,7 @@ public class ClassNode extends ClassVisitor {
/**
* The internal names of the interfaces directly implemented by this class (see {@link
- * org.objectweb.asm.Type#getInternalName}).
+ * org.objectweb.asm.Type#getInternalName()}).
*/
public List<String> interfaces;
@@ -89,8 +89,9 @@ public class ClassNode extends ClassVisitor {
public ModuleNode module;
/**
- * The internal name of the enclosing class of this class. Must be {@literal null} if this class
- * has no enclosing class, or if it is a local or anonymous class.
+ * The internal name of the enclosing class of this class (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). Must be {@literal null} if this class has no
+ * enclosing class, or if it is a local or anonymous class.
*/
public String outerClass;
@@ -128,13 +129,22 @@ public class ClassNode extends ClassVisitor {
/** The inner classes of this class. */
public List<InnerClassNode> innerClasses;
- /** The internal name of the nest host class of this class. May be {@literal null}. */
+ /**
+ * The internal name of the nest host class of this class (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
+ */
public String nestHostClass;
- /** The internal names of the nest members of this class. May be {@literal null}. */
+ /**
+ * The internal names of the nest members of this class (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
+ */
public List<String> nestMembers;
- /** The internal names of the permitted subclasses of this class. May be {@literal null}. */
+ /**
+ * The internal names of the permitted subclasses of this class (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
+ */
public List<String> permittedSubclasses;
/** The record components of this class. May be {@literal null}. */
diff --git a/asm-tree/src/main/java/org/objectweb/asm/tree/FieldInsnNode.java b/asm-tree/src/main/java/org/objectweb/asm/tree/FieldInsnNode.java
index e5693c0b..ed8b1048 100644
--- a/asm-tree/src/main/java/org/objectweb/asm/tree/FieldInsnNode.java
+++ b/asm-tree/src/main/java/org/objectweb/asm/tree/FieldInsnNode.java
@@ -40,7 +40,7 @@ public class FieldInsnNode extends AbstractInsnNode {
/**
* The internal name of the field's owner class (see {@link
- * org.objectweb.asm.Type#getInternalName}).
+ * org.objectweb.asm.Type#getInternalName()}).
*/
public String owner;
@@ -56,7 +56,7 @@ public class FieldInsnNode extends AbstractInsnNode {
* @param opcode the opcode of the type instruction to be constructed. This opcode must be
* GETSTATIC, PUTSTATIC, GETFIELD or PUTFIELD.
* @param owner the internal name of the field's owner class (see {@link
- * org.objectweb.asm.Type#getInternalName}).
+ * org.objectweb.asm.Type#getInternalName()}).
* @param name the field's name.
* @param descriptor the field's descriptor (see {@link org.objectweb.asm.Type}).
*/
diff --git a/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleExportNode.java b/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleExportNode.java
index 6abb96e8..f860d26d 100644
--- a/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleExportNode.java
+++ b/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleExportNode.java
@@ -37,7 +37,10 @@ import org.objectweb.asm.ModuleVisitor;
*/
public class ModuleExportNode {
- /** The internal name of the exported package. */
+ /**
+ * The internal name of the exported package (see {@link
+ * org.objectweb.asm.Type#getInternalName()}).
+ */
public String packaze;
/**
@@ -55,7 +58,8 @@ public class ModuleExportNode {
/**
* Constructs a new {@link ModuleExportNode}.
*
- * @param packaze the internal name of the exported package.
+ * @param packaze the internal name of the exported package (see {@link
+ * org.objectweb.asm.Type#getInternalName()}).
* @param access the package access flags, one or more of {@code ACC_SYNTHETIC} and {@code
* ACC_MANDATED}.
* @param modules a list of modules that can access this exported package, specified with fully
diff --git a/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleNode.java b/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleNode.java
index 03881835..3f7a3305 100644
--- a/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleNode.java
+++ b/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleNode.java
@@ -52,10 +52,16 @@ public class ModuleNode extends ModuleVisitor {
/** The version of this module. May be {@literal null}. */
public String version;
- /** The internal name of the main class of this module. May be {@literal null}. */
+ /**
+ * The internal name of the main class of this module (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
+ */
public String mainClass;
- /** The internal name of the packages declared by this module. May be {@literal null}. */
+ /**
+ * The internal name of the packages declared by this module (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
+ */
public List<String> packages;
/** The dependencies of this module. May be {@literal null}. */
@@ -67,7 +73,10 @@ public class ModuleNode extends ModuleVisitor {
/** The packages opened by this module. May be {@literal null}. */
public List<ModuleOpenNode> opens;
- /** The internal names of the services used by this module. May be {@literal null}. */
+ /**
+ * The internal names of the services used by this module (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
+ */
public List<String> uses;
/** The services provided by this module. May be {@literal null}. */
@@ -106,7 +115,8 @@ public class ModuleNode extends ModuleVisitor {
* @param requires The dependencies of this module. May be {@literal null}.
* @param exports The packages exported by this module. May be {@literal null}.
* @param opens The packages opened by this module. May be {@literal null}.
- * @param uses The internal names of the services used by this module. May be {@literal null}.
+ * @param uses The internal names of the services used by this module (see {@link
+ * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
* @param provides The services provided by this module. May be {@literal null}.
*/
public ModuleNode(
diff --git a/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleOpenNode.java b/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleOpenNode.java
index bcbb6480..fc73def3 100644
--- a/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleOpenNode.java
+++ b/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleOpenNode.java
@@ -37,7 +37,9 @@ import org.objectweb.asm.ModuleVisitor;
*/
public class ModuleOpenNode {
- /** The internal name of the opened package. */
+ /**
+ * The internal name of the opened package (see {@link org.objectweb.asm.Type#getInternalName()}).
+ */
public String packaze;
/**
@@ -55,7 +57,8 @@ public class ModuleOpenNode {
/**
* Constructs a new {@link ModuleOpenNode}.
*
- * @param packaze the internal name of the opened package.
+ * @param packaze the internal name of the opened package (see {@link
+ * org.objectweb.asm.Type#getInternalName()}).
* @param access the access flag of the opened package, valid values are among {@code
* ACC_SYNTHETIC} and {@code ACC_MANDATED}.
* @param modules the fully qualified names (using dots) of the modules that can use deep
diff --git a/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleProvideNode.java b/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleProvideNode.java
index 601c7fd9..c0976d47 100644
--- a/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleProvideNode.java
+++ b/asm-tree/src/main/java/org/objectweb/asm/tree/ModuleProvideNode.java
@@ -37,10 +37,13 @@ import org.objectweb.asm.ModuleVisitor;
*/
public class ModuleProvideNode {
- /** The internal name of the service. */
+ /** The internal name of the service (see {@link org.objectweb.asm.Type#getInternalName()}). */
public String service;
- /** The internal names of the implementations of the service (there is at least one provider). */
+ /**
+ * The internal names of the implementations of the service (there is at least one provider). See
+ * {@link org.objectweb.asm.Type#getInternalName()}.
+ */
public List<String> providers;
/**
@@ -48,7 +51,7 @@ public class ModuleProvideNode {
*
* @param service the internal name of the service.
* @param providers the internal names of the implementations of the service (there is at least
- * one provider).
+ * one provider). See {@link org.objectweb.asm.Type#getInternalName()}.
*/
public ModuleProvideNode(final String service, final List<String> providers) {
this.service = service;
diff --git a/asm-tree/src/main/java/org/objectweb/asm/tree/TryCatchBlockNode.java b/asm-tree/src/main/java/org/objectweb/asm/tree/TryCatchBlockNode.java
index cdc5a3ff..30bfd698 100644
--- a/asm-tree/src/main/java/org/objectweb/asm/tree/TryCatchBlockNode.java
+++ b/asm-tree/src/main/java/org/objectweb/asm/tree/TryCatchBlockNode.java
@@ -66,8 +66,9 @@ public class TryCatchBlockNode {
* @param start the beginning of the exception handler's scope (inclusive).
* @param end the end of the exception handler's scope (exclusive).
* @param handler the beginning of the exception handler's code.
- * @param type the internal name of the type of exceptions handled by the handler, or {@literal
- * null} to catch any exceptions (for "finally" blocks).
+ * @param type the internal name of the type of exceptions handled by the handler (see {@link
+ * org.objectweb.asm.Type#getInternalName()}), or {@literal null} to catch any exceptions (for
+ * "finally" blocks).
*/
public TryCatchBlockNode(
final LabelNode start, final LabelNode end, final LabelNode handler, final String type) {
diff --git a/asm-tree/src/main/java/org/objectweb/asm/tree/TypeInsnNode.java b/asm-tree/src/main/java/org/objectweb/asm/tree/TypeInsnNode.java
index 0c5a438a..d7459877 100644
--- a/asm-tree/src/main/java/org/objectweb/asm/tree/TypeInsnNode.java
+++ b/asm-tree/src/main/java/org/objectweb/asm/tree/TypeInsnNode.java
@@ -32,7 +32,7 @@ import org.objectweb.asm.MethodVisitor;
/**
* A node that represents a type instruction. A type instruction is an instruction which takes an
- * internal name as parameter.
+ * internal name as parameter (see {@link org.objectweb.asm.Type#getInternalName()}).
*
* @author Eric Bruneton
*/
@@ -40,7 +40,7 @@ public class TypeInsnNode extends AbstractInsnNode {
/**
* The operand of this instruction. Despite its name (due to historical reasons), this operand is
- * an internal name (see {@link org.objectweb.asm.Type}).
+ * an internal name (see {@link org.objectweb.asm.Type#getInternalName()}).
*/
public String desc;
@@ -50,7 +50,7 @@ public class TypeInsnNode extends AbstractInsnNode {
* @param opcode the opcode of the type instruction to be constructed. This opcode must be NEW,
* ANEWARRAY, CHECKCAST or INSTANCEOF.
* @param type the operand of the instruction to be constructed. This operand is an internal name
- * (see {@link org.objectweb.asm.Type}).
+ * (see {@link org.objectweb.asm.Type#getInternalName()}).
*/
public TypeInsnNode(final int opcode, final String type) {
super(opcode);
diff --git a/asm-util/src/main/java/org/objectweb/asm/util/Printer.java b/asm-util/src/main/java/org/objectweb/asm/util/Printer.java
index 264961bd..7e66cafe 100644
--- a/asm-util/src/main/java/org/objectweb/asm/util/Printer.java
+++ b/asm-util/src/main/java/org/objectweb/asm/util/Printer.java
@@ -338,15 +338,14 @@ public abstract class Printer {
* and the major version in the 16 least significant bits.
* @param access the class's access flags (see {@link Opcodes}). This parameter also indicates if
* the class is deprecated.
- * @param name the internal name of the class (see {@link
- * org.objectweb.asm.Type#getInternalName()}).
+ * @param name the internal name of the class (see {@link Type#getInternalName()}).
* @param signature the signature of this class. May be {@literal null} if the class is not a
* generic one, and does not extend or implement generic classes or interfaces.
- * @param superName the internal of name of the super class (see {@link
- * org.objectweb.asm.Type#getInternalName()}). For interfaces, the super class is {@link
- * Object}. May be {@literal null}, but only for the {@link Object} class.
+ * @param superName the internal of name of the super class (see {@link Type#getInternalName()}).
+ * For interfaces, the super class is {@link Object}. May be {@literal null}, but only for the
+ * {@link Object} class.
* @param interfaces the internal names of the class's interfaces (see {@link
- * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
+ * Type#getInternalName()}). May be {@literal null}.
*/
public abstract void visit(
int version,
@@ -387,7 +386,8 @@ public abstract class Printer {
* implicitly its own nest, so it's invalid to call this method with the visited class name as
* argument.
*
- * @param nestHost the internal name of the host class of the nest.
+ * @param nestHost the internal name of the host class of the nest (see {@link
+ * Type#getInternalName()}).
*/
public void visitNestHost(final String nestHost) {
throw new UnsupportedOperationException(UNSUPPORTED_OPERATION);
@@ -396,7 +396,8 @@ public abstract class Printer {
/**
* Class outer class. See {@link org.objectweb.asm.ClassVisitor#visitOuterClass}.
*
- * @param owner internal name of the enclosing class of the class.
+ * @param owner internal name of the enclosing class of the class (see {@link
+ * Type#getInternalName()}).
* @param name the name of the method that contains the class, or {@literal null} if the class is
* not enclosed in a method of its enclosing class.
* @param descriptor the descriptor of the method that contains the class, or {@literal null} if
@@ -417,10 +418,9 @@ public abstract class Printer {
* Class type annotation. See {@link org.objectweb.asm.ClassVisitor#visitTypeAnnotation}.
*
* @param typeRef a reference to the annotated type. The sort of this type reference must be
- * {@link org.objectweb.asm.TypeReference#CLASS_TYPE_PARAMETER}, {@link
- * org.objectweb.asm.TypeReference#CLASS_TYPE_PARAMETER_BOUND} or {@link
- * org.objectweb.asm.TypeReference#CLASS_EXTENDS}. See {@link
- * org.objectweb.asm.TypeReference}.
+ * {@link TypeReference#CLASS_TYPE_PARAMETER}, {@link
+ * TypeReference#CLASS_TYPE_PARAMETER_BOUND} or {@link TypeReference#CLASS_EXTENDS}. See
+ * {@link TypeReference}.
* @param typePath the path to the annotated type argument, wildcard bound, array element type, or
* static inner type within 'typeRef'. May be {@literal null} if the annotation targets
* 'typeRef' as a whole.
@@ -447,7 +447,7 @@ public abstract class Printer {
* the visited class is the host of a nest. A nest host is implicitly a member of its own nest, so
* it's invalid to call this method with the visited class name as argument.
*
- * @param nestMember the internal name of a nest member.
+ * @param nestMember the internal name of a nest member (see {@link Type#getInternalName()}).
*/
public void visitNestMember(final String nestMember) {
throw new UnsupportedOperationException(UNSUPPORTED_OPERATION);
@@ -457,7 +457,8 @@ public abstract class Printer {
* Visits a permitted subclasses. A permitted subclass is one of the allowed subclasses of the
* current class. See {@link org.objectweb.asm.ClassVisitor#visitPermittedSubclass(String)}.
*
- * @param permittedSubclass the internal name of a permitted subclass.
+ * @param permittedSubclass the internal name of a permitted subclass (see {@link
+ * Type#getInternalName()}).
*/
public void visitPermittedSubclass(final String permittedSubclass) {
throw new UnsupportedOperationException(UNSUPPORTED_OPERATION);
@@ -466,10 +467,9 @@ public abstract class Printer {
/**
* Class inner name. See {@link org.objectweb.asm.ClassVisitor#visitInnerClass}.
*
- * @param name the internal name of an inner class (see {@link
- * org.objectweb.asm.Type#getInternalName()}).
+ * @param name the internal name of an inner class (see {@link Type#getInternalName()}).
* @param outerName the internal name of the class to which the inner class belongs (see {@link
- * org.objectweb.asm.Type#getInternalName()}). May be {@literal null} for not member classes.
+ * Type#getInternalName()}). May be {@literal null} for not member classes.
* @param innerName the (simple) name of the inner class inside its enclosing class. May be
* {@literal null} for anonymous inner classes.
* @param access the access flags of the inner class as originally declared in the enclosing
@@ -499,7 +499,7 @@ public abstract class Printer {
* @param access the field's access flags (see {@link Opcodes}). This parameter also indicates if
* the field is synthetic and/or deprecated.
* @param name the field's name.
- * @param descriptor the field's descriptor (see {@link org.objectweb.asm.Type}).
+ * @param descriptor the field's descriptor (see {@link Type}).
* @param signature the field's signature. May be {@literal null} if the field's type does not use
* generic types.
* @param value the field's initial value. This parameter, which may be {@literal null} if the
@@ -519,11 +519,11 @@ public abstract class Printer {
* @param access the method's access flags (see {@link Opcodes}). This parameter also indicates if
* the method is synthetic and/or deprecated.
* @param name the method's name.
- * @param descriptor the method's descriptor (see {@link org.objectweb.asm.Type}).
+ * @param descriptor the method's descriptor (see {@link Type}).
* @param signature the method's signature. May be {@literal null} if the method parameters,
* return type and exceptions do not use generic types.
* @param exceptions the internal names of the method's exception classes (see {@link
- * org.objectweb.asm.Type#getInternalName()}). May be {@literal null}.
+ * Type#getInternalName()}). May be {@literal null}.
* @return the printer.
*/
public abstract Printer visitMethod(
@@ -539,7 +539,8 @@ public abstract class Printer {
/**
* Module main class. See {@link org.objectweb.asm.ModuleVisitor#visitMainClass}.
*
- * @param mainClass the internal name of the main class of the current module.
+ * @param mainClass the internal name of the main class of the current module (see {@link
+ * Type#getInternalName()}).
*/
public void visitMainClass(final String mainClass) {
throw new UnsupportedOperationException(UNSUPPORTED_OPERATION);
@@ -548,7 +549,7 @@ public abstract class Printer {
/**
* Module package. See {@link org.objectweb.asm.ModuleVisitor#visitPackage}.
*
- * @param packaze the internal name of a package.
+ * @param packaze the internal name of a package (see {@link Type#getInternalName()}).
*/
public void visitPackage(final String packaze) {
throw new UnsupportedOperationException(UNSUPPORTED_OPERATION);
@@ -569,7 +570,7 @@ public abstract class Printer {
/**
* Module export. See {@link org.objectweb.asm.ModuleVisitor#visitExport}.
*
- * @param packaze the internal name of the exported package.
+ * @param packaze the internal name of the exported package (see {@link Type#getInternalName()}).
* @param access the access flag of the exported package, valid values are among {@code
* ACC_SYNTHETIC} and {@code ACC_MANDATED}.
* @param modules the fully qualified names (using dots) of the modules that can access the public
@@ -582,7 +583,7 @@ public abstract class Printer {
/**
* Module open. See {@link org.objectweb.asm.ModuleVisitor#visitOpen}.
*
- * @param packaze the internal name of the opened package.
+ * @param packaze the internal name of the opened package (see {@link Type#getInternalName()}).
* @param access the access flag of the opened package, valid values are among {@code
* ACC_SYNTHETIC} and {@code ACC_MANDATED}.
* @param modules the fully qualified names (using dots) of the modules that can use deep
@@ -595,7 +596,7 @@ public abstract class Printer {
/**
* Module use. See {@link org.objectweb.asm.ModuleVisitor#visitUse}.
*
- * @param service the internal name of the service.
+ * @param service the internal name of the service (see {@link Type#getInternalName()}).
*/
public void visitUse(final String service) {
throw new UnsupportedOperationException(UNSUPPORTED_OPERATION);
@@ -604,7 +605,7 @@ public abstract class Printer {
/**
* Module provide. See {@link org.objectweb.asm.ModuleVisitor#visitProvide}.
*
- * @param service the internal name of the service.
+ * @param service the internal name of the service (see {@link Type#getInternalName()}).
* @param providers the internal names of the implementations of the service (there is at least
* one provider).
*/
@@ -627,10 +628,10 @@ public abstract class Printer {
* @param name the value name.
* @param value the actual value, whose type must be {@link Byte}, {@link Boolean}, {@link
* Character}, {@link Short}, {@link Integer} , {@link Long}, {@link Float}, {@link Double},
- * {@link String} or {@link org.objectweb.asm.Type} of {@link org.objectweb.asm.Type#OBJECT}
- * or {@link org.objectweb.asm.Type#ARRAY} sort. This value can also be an array of byte,
- * boolean, short, char, int, long, float or double values (this is equivalent to using {@link
- * #visitArray} and visiting each array element in turn, but is more convenient).
+ * {@link String} or {@link Type} of {@link Type#OBJECT} or {@link Type#ARRAY} sort. This
+ * value can also be an array of byte, boolean, short, char, int, long, float or double values
+ * (this is equivalent to using {@link #visitArray} and visiting each array element in turn,
+ * but is more convenient).
*/
// DontCheck(OverloadMethodsDeclarationOrder): overloads are semantically different.
public abstract void visit(String name, Object value);
@@ -738,7 +739,7 @@ public abstract class Printer {
* Field type annotation. See {@link org.objectweb.asm.FieldVisitor#visitTypeAnnotation}.
*
* @param typeRef a reference to the annotated type. The sort of this type reference must be
- * {@link org.objectweb.asm.TypeReference#FIELD}. See {@link org.objectweb.asm.TypeReference}.
+ * {@link TypeReference#FIELD}. See {@link TypeReference}.
* @param typePath the path to the annotated type argument, wildcard bound, array element type, or
* static inner type within 'typeRef'. May be {@literal null} if the annotation targets
* 'typeRef' as a whole.
@@ -796,12 +797,10 @@ public abstract class Printer {
* Method type annotation. See {@link org.objectweb.asm.MethodVisitor#visitTypeAnnotation}.
*
* @param typeRef a reference to the annotated type. The sort of this type reference must be
- * {@link org.objectweb.asm.TypeReference#METHOD_TYPE_PARAMETER}, {@link
- * org.objectweb.asm.TypeReference#METHOD_TYPE_PARAMETER_BOUND}, {@link
- * org.objectweb.asm.TypeReference#METHOD_RETURN}, {@link
- * org.objectweb.asm.TypeReference#METHOD_RECEIVER}, {@link
- * org.objectweb.asm.TypeReference#METHOD_FORMAL_PARAMETER} or {@link
- * org.objectweb.asm.TypeReference#THROWS}. See {@link org.objectweb.asm.TypeReference}.
+ * {@link TypeReference#METHOD_TYPE_PARAMETER}, {@link
+ * TypeReference#METHOD_TYPE_PARAMETER_BOUND}, {@link TypeReference#METHOD_RETURN}, {@link
+ * TypeReference#METHOD_RECEIVER}, {@link TypeReference#METHOD_FORMAL_PARAMETER} or {@link
+ * TypeReference#THROWS}. See {@link TypeReference}.
* @param typePath the path to the annotated type argument, wildcard bound, array element type, or
* static inner type within 'typeRef'. May be {@literal null} if the annotation targets
* 'typeRef' as a whole.
@@ -870,9 +869,9 @@ public abstract class Printer {
* types are represented by {@link Opcodes#TOP}, {@link Opcodes#INTEGER}, {@link
* Opcodes#FLOAT}, {@link Opcodes#LONG}, {@link Opcodes#DOUBLE}, {@link Opcodes#NULL} or
* {@link Opcodes#UNINITIALIZED_THIS} (long and double are represented by a single element).
- * Reference types are represented by String objects (representing internal names), and
- * uninitialized types by Label objects (this label designates the NEW instruction that
- * created this uninitialized value).
+ * Reference types are represented by String objects (representing internal names, see {@link
+ * Type#getInternalName()}), and uninitialized types by Label objects (this label designates
+ * the NEW instruction that created this uninitialized value).
* @param numStack the number of operand stack elements in the visited frame.
* @param stack the operand stack types in this frame. This array must not be modified. Its
* content has the same format as the "local" array.
@@ -928,7 +927,7 @@ public abstract class Printer {
* @param opcode the opcode of the type instruction to be visited. This opcode is either NEW,
* ANEWARRAY, CHECKCAST or INSTANCEOF.
* @param type the operand of the instruction to be visited. This operand must be the internal
- * name of an object or array class (see {@link org.objectweb.asm.Type#getInternalName()}).
+ * name of an object or array class (see {@link Type#getInternalName()}).
*/
public abstract void visitTypeInsn(int opcode, String type);
@@ -937,10 +936,9 @@ public abstract class Printer {
*
* @param opcode the opcode of the type instruction to be visited. This opcode is either
* GETSTATIC, PUTSTATIC, GETFIELD or PUTFIELD.
- * @param owner the internal name of the field's owner class (see {@link
- * org.objectweb.asm.Type#getInternalName()}).
+ * @param owner the internal name of the field's owner class (see {@link Type#getInternalName()}).
* @param name the field's name.
- * @param descriptor the field's descriptor (see {@link org.objectweb.asm.Type}).
+ * @param descriptor the field's descriptor (see {@link Type}).
*/
public abstract void visitFieldInsn(int opcode, String owner, String name, String descriptor);
@@ -950,9 +948,9 @@ public abstract class Printer {
* @param opcode the opcode of the type instruction to be visited. This opcode is either
* INVOKEVIRTUAL, INVOKESPECIAL, INVOKESTATIC or INVOKEINTERFACE.
* @param owner the internal name of the method's owner class (see {@link
- * org.objectweb.asm.Type#getInternalName()}).
+ * Type#getInternalName()}).
* @param name the method's name.
- * @param descriptor the method's descriptor (see {@link org.objectweb.asm.Type}).
+ * @param descriptor the method's descriptor (see {@link Type}).
* @deprecated use {@link #visitMethodInsn(int, String, String, String, boolean)} instead.
*/
@Deprecated
@@ -970,9 +968,9 @@ public abstract class Printer {
* @param opcode the opcode of the type instruction to be visited. This opcode is either
* INVOKEVIRTUAL, INVOKESPECIAL, INVOKESTATIC or INVOKEINTERFACE.
* @param owner the internal name of the method's owner class (see {@link
- * org.objectweb.asm.Type#getInternalName()}).
+ * Type#getInternalName()}).
* @param name the method's name.
- * @param descriptor the method's descriptor (see {@link org.objectweb.asm.Type}).
+ * @param descriptor the method's descriptor (see {@link Type}).
* @param isInterface if the method's owner class is an interface.
*/
public void visitMethodInsn(
@@ -988,12 +986,12 @@ public abstract class Printer {
* Method instruction. See {@link org.objectweb.asm.MethodVisitor#visitInvokeDynamicInsn}.
*
* @param name the method's name.
- * @param descriptor the method's descriptor (see {@link org.objectweb.asm.Type}).
+ * @param descriptor the method's descriptor (see {@link Type}).
* @param bootstrapMethodHandle the bootstrap method.
* @param bootstrapMethodArguments the bootstrap method constant arguments. Each argument must be
* an {@link Integer}, {@link Float}, {@link Long}, {@link Double}, {@link String}, {@link
- * org.objectweb.asm.Type} or {@link Handle} value. This method is allowed to modify the
- * content of the array so a caller should expect that this array may change.
+ * Type} or {@link Handle} value. This method is allowed to modify the content of the array so
+ * a caller should expect that this array may change.
*/
public abstract void visitInvokeDynamicInsn(
String name,
@@ -1063,7 +1061,7 @@ public abstract class Printer {
/**
* Method instruction. See {@link org.objectweb.asm.MethodVisitor#visitMultiANewArrayInsn}.
*
- * @param descriptor an array type descriptor (see {@link org.objectweb.asm.Type}).
+ * @param descriptor an array type descriptor (see {@link Type}).
* @param numDimensions the number of dimensions of the array to allocate.
*/
public abstract void visitMultiANewArrayInsn(String descriptor, int numDimensions);
@@ -1072,16 +1070,12 @@ public abstract class Printer {
* Instruction type annotation. See {@link org.objectweb.asm.MethodVisitor#visitInsnAnnotation}.
*
* @param typeRef a reference to the annotated type. The sort of this type reference must be
- * {@link org.objectweb.asm.TypeReference#INSTANCEOF}, {@link
- * org.objectweb.asm.TypeReference#NEW}, {@link
- * org.objectweb.asm.TypeReference#CONSTRUCTOR_REFERENCE}, {@link
- * org.objectweb.asm.TypeReference#METHOD_REFERENCE}, {@link
- * org.objectweb.asm.TypeReference#CAST}, {@link
- * org.objectweb.asm.TypeReference#CONSTRUCTOR_INVOCATION_TYPE_ARGUMENT}, {@link
- * org.objectweb.asm.TypeReference#METHOD_INVOCATION_TYPE_ARGUMENT}, {@link
- * org.objectweb.asm.TypeReference#CONSTRUCTOR_REFERENCE_TYPE_ARGUMENT}, or {@link
- * org.objectweb.asm.TypeReference#METHOD_REFERENCE_TYPE_ARGUMENT}. See {@link
- * org.objectweb.asm.TypeReference}.
+ * {@link TypeReference#INSTANCEOF}, {@link TypeReference#NEW}, {@link
+ * TypeReference#CONSTRUCTOR_REFERENCE}, {@link TypeReference#METHOD_REFERENCE}, {@link
+ * TypeReference#CAST}, {@link TypeReference#CONSTRUCTOR_INVOCATION_TYPE_ARGUMENT}, {@link
+ * TypeReference#METHOD_INVOCATION_TYPE_ARGUMENT}, {@link
+ * TypeReference#CONSTRUCTOR_REFERENCE_TYPE_ARGUMENT}, or {@link
+ * TypeReference#METHOD_REFERENCE_TYPE_ARGUMENT}. See {@link TypeReference}.
* @param typePath the path to the annotated type argument, wildcard bound, array element type, or
* static inner type within 'typeRef'. May be {@literal null} if the annotation targets
* 'typeRef' as a whole.
@@ -1100,8 +1094,9 @@ public abstract class Printer {
* @param start the beginning of the exception handler's scope (inclusive).
* @param end the end of the exception handler's scope (exclusive).
* @param handler the beginning of the exception handler's code.
- * @param type the internal name of the type of exceptions handled by the handler, or {@literal
- * null} to catch any exceptions (for "finally" blocks).
+ * @param type the internal name of the type of exceptions handled by the handler (see {@link
+ * Type#getInternalName()}), or {@literal null} to catch any exceptions (for "finally"
+ * blocks).
*/
public abstract void visitTryCatchBlock(Label start, Label end, Label handler, String type);
@@ -1110,8 +1105,7 @@ public abstract class Printer {
* org.objectweb.asm.MethodVisitor#visitTryCatchAnnotation}.
*
* @param typeRef a reference to the annotated type. The sort of this type reference must be
- * {@link org.objectweb.asm.TypeReference#EXCEPTION_PARAMETER}. See {@link
- * org.objectweb.asm.TypeReference}.
+ * {@link TypeReference#EXCEPTION_PARAMETER}. See {@link TypeReference}.
* @param typePath the path to the annotated type argument, wildcard bound, array element type, or
* static inner type within 'typeRef'. May be {@literal null} if the annotation targets
* 'typeRef' as a whole.
@@ -1144,9 +1138,8 @@ public abstract class Printer {
* org.objectweb.asm.MethodVisitor#visitTryCatchAnnotation}.
*
* @param typeRef a reference to the annotated type. The sort of this type reference must be
- * {@link org.objectweb.asm.TypeReference#LOCAL_VARIABLE} or {@link
- * org.objectweb.asm.TypeReference#RESOURCE_VARIABLE}. See {@link
- * org.objectweb.asm.TypeReference}.
+ * {@link TypeReference#LOCAL_VARIABLE} or {@link TypeReference#RESOURCE_VARIABLE}. See {@link
+ * TypeReference}.
* @param typePath the path to the annotated type argument, wildcard bound, array element type, or
* static inner type within 'typeRef'. May be {@literal null} if the annotation targets
* 'typeRef' as a whole.
diff --git a/asm/src/main/java/org/objectweb/asm/ClassReader.java b/asm/src/main/java/org/objectweb/asm/ClassReader.java
index 2a1139c3..7f0e4e72 100644
--- a/asm/src/main/java/org/objectweb/asm/ClassReader.java
+++ b/asm/src/main/java/org/objectweb/asm/ClassReader.java
@@ -375,7 +375,7 @@ public class ClassReader {
}
/**
- * Returns the internal of name of the super class (see {@link Type#getInternalName()}). For
+ * Returns the internal name of the super class (see {@link Type#getInternalName()}). For
* interfaces, the super class is {@link Object}.
*
* @return the internal name of the super class, or {@literal null} for {@link Object} class.
diff --git a/asm/src/main/java/org/objectweb/asm/ClassTooLargeException.java b/asm/src/main/java/org/objectweb/asm/ClassTooLargeException.java
index 80037b1d..de177b1e 100644
--- a/asm/src/main/java/org/objectweb/asm/ClassTooLargeException.java
+++ b/asm/src/main/java/org/objectweb/asm/ClassTooLargeException.java
@@ -42,7 +42,8 @@ public final class ClassTooLargeException extends IndexOutOfBoundsException {
/**
* Constructs a new {@link ClassTooLargeException}.
*
- * @param className the internal name of the class.
+ * @param className the internal name of the class (see {@link
+ * org.objectweb.asm.Type#getInternalName()}).
* @param constantPoolCount the number of constant pool items of the class.
*/
public ClassTooLargeException(final String className, final int constantPoolCount) {
@@ -52,7 +53,7 @@ public final class ClassTooLargeException extends IndexOutOfBoundsException {
}
/**
- * Returns the internal name of the class.
+ * Returns the internal name of the class (see {@link org.objectweb.asm.Type#getInternalName()}).
*
* @return the internal name of the class.
*/
diff --git a/asm/src/main/java/org/objectweb/asm/ClassVisitor.java b/asm/src/main/java/org/objectweb/asm/ClassVisitor.java
index a557f9e4..95fd38e3 100644
--- a/asm/src/main/java/org/objectweb/asm/ClassVisitor.java
+++ b/asm/src/main/java/org/objectweb/asm/ClassVisitor.java
@@ -157,7 +157,8 @@ public abstract class ClassVisitor {
* implicitly its own nest, so it's invalid to call this method with the visited class name as
* argument.
*
- * @param nestHost the internal name of the host class of the nest.
+ * @param nestHost the internal name of the host class of the nest (see {@link
+ * Type#getInternalName()}).
*/
public void visitNestHost(final String nestHost) {
if (api < Opcodes.ASM7) {
@@ -172,7 +173,8 @@ public abstract class ClassVisitor {
* Visits the enclosing class of the class. This method must be called only if this class is a
* local or anonymous class. See the JVMS 4.7.7 section for more details.
*
- * @param owner internal name of the enclosing class of the class.
+ * @param owner internal name of the enclosing class of the class (see {@link
+ * Type#getInternalName()}).
* @param name the name of the method that contains the class, or {@literal null} if the class is
* not enclosed in a method or constructor of its enclosing class (e.g. if it is enclosed in
* an instance initializer, static initializer, instance variable initializer, or class
@@ -247,7 +249,7 @@ public abstract class ClassVisitor {
* the visited class is the host of a nest. A nest host is implicitly a member of its own nest, so
* it's invalid to call this method with the visited class name as argument.
*
- * @param nestMember the internal name of a nest member.
+ * @param nestMember the internal name of a nest member (see {@link Type#getInternalName()}).
*/
public void visitNestMember(final String nestMember) {
if (api < Opcodes.ASM7) {
@@ -262,7 +264,8 @@ public abstract class ClassVisitor {
* Visits a permitted subclasses. A permitted subclass is one of the allowed subclasses of the
* current class.
*
- * @param permittedSubclass the internal name of a permitted subclass.
+ * @param permittedSubclass the internal name of a permitted subclass (see {@link
+ * Type#getInternalName()}).
*/
public void visitPermittedSubclass(final String permittedSubclass) {
if (api < Opcodes.ASM9) {
diff --git a/asm/src/main/java/org/objectweb/asm/ClassWriter.java b/asm/src/main/java/org/objectweb/asm/ClassWriter.java
index bfe0e605..078efa20 100644
--- a/asm/src/main/java/org/objectweb/asm/ClassWriter.java
+++ b/asm/src/main/java/org/objectweb/asm/ClassWriter.java
@@ -842,7 +842,7 @@ public class ClassWriter extends ClassVisitor {
* constant pool already contains a similar item. <i>This method is intended for {@link Attribute}
* sub classes, and is normally not needed by class generators or adapters.</i>
*
- * @param value the internal name of the class.
+ * @param value the internal name of the class (see {@link Type#getInternalName()}).
* @return the index of a new or already existing class reference item.
*/
public int newClass(final String value) {
@@ -894,7 +894,8 @@ public class ClassWriter extends ClassVisitor {
* Opcodes#H_GETSTATIC}, {@link Opcodes#H_PUTFIELD}, {@link Opcodes#H_PUTSTATIC}, {@link
* Opcodes#H_INVOKEVIRTUAL}, {@link Opcodes#H_INVOKESTATIC}, {@link Opcodes#H_INVOKESPECIAL},
* {@link Opcodes#H_NEWINVOKESPECIAL} or {@link Opcodes#H_INVOKEINTERFACE}.
- * @param owner the internal name of the field or method owner class.
+ * @param owner the internal name of the field or method owner class (see {@link
+ * Type#getInternalName()}).
* @param name the name of the field or method.
* @param descriptor the descriptor of the field or method.
* @return the index of a new or already existing method type reference item.
@@ -916,7 +917,8 @@ public class ClassWriter extends ClassVisitor {
* Opcodes#H_GETSTATIC}, {@link Opcodes#H_PUTFIELD}, {@link Opcodes#H_PUTSTATIC}, {@link
* Opcodes#H_INVOKEVIRTUAL}, {@link Opcodes#H_INVOKESTATIC}, {@link Opcodes#H_INVOKESPECIAL},
* {@link Opcodes#H_NEWINVOKESPECIAL} or {@link Opcodes#H_INVOKEINTERFACE}.
- * @param owner the internal name of the field or method owner class.
+ * @param owner the internal name of the field or method owner class (see {@link
+ * Type#getInternalName()}).
* @param name the name of the field or method.
* @param descriptor the descriptor of the field or method.
* @param isInterface true if the owner is an interface.
@@ -978,7 +980,7 @@ public class ClassWriter extends ClassVisitor {
* constant pool already contains a similar item. <i>This method is intended for {@link Attribute}
* sub classes, and is normally not needed by class generators or adapters.</i>
*
- * @param owner the internal name of the field's owner class.
+ * @param owner the internal name of the field's owner class (see {@link Type#getInternalName()}).
* @param name the field's name.
* @param descriptor the field's descriptor.
* @return the index of a new or already existing field reference item.
@@ -992,7 +994,8 @@ public class ClassWriter extends ClassVisitor {
* constant pool already contains a similar item. <i>This method is intended for {@link Attribute}
* sub classes, and is normally not needed by class generators or adapters.</i>
*
- * @param owner the internal name of the method's owner class.
+ * @param owner the internal name of the method's owner class (see {@link
+ * Type#getInternalName()}).
* @param name the method's name.
* @param descriptor the method's descriptor.
* @param isInterface {@literal true} if {@code owner} is an interface.
@@ -1028,9 +1031,10 @@ public class ClassWriter extends ClassVisitor {
* currently being generated by this ClassWriter, which can of course not be loaded since it is
* under construction.
*
- * @param type1 the internal name of a class.
- * @param type2 the internal name of another class.
- * @return the internal name of the common super class of the two given classes.
+ * @param type1 the internal name of a class (see {@link Type#getInternalName()}).
+ * @param type2 the internal name of another class (see {@link Type#getInternalName()}).
+ * @return the internal name of the common super class of the two given classes (see {@link
+ * Type#getInternalName()}).
*/
protected String getCommonSuperClass(final String type1, final String type2) {
ClassLoader classLoader = getClassLoader();
diff --git a/asm/src/main/java/org/objectweb/asm/Handle.java b/asm/src/main/java/org/objectweb/asm/Handle.java
index ec4f2497..6ffae75b 100644
--- a/asm/src/main/java/org/objectweb/asm/Handle.java
+++ b/asm/src/main/java/org/objectweb/asm/Handle.java
@@ -65,7 +65,7 @@ public final class Handle {
* {@link Opcodes#H_INVOKESPECIAL}, {@link Opcodes#H_NEWINVOKESPECIAL} or {@link
* Opcodes#H_INVOKEINTERFACE}.
* @param owner the internal name of the class that owns the field or method designated by this
- * handle.
+ * handle (see {@link Type#getInternalName()}).
* @param name the name of the field or method designated by this handle.
* @param descriptor the descriptor of the field or method designated by this handle.
* @deprecated this constructor has been superseded by {@link #Handle(int, String, String, String,
@@ -85,7 +85,7 @@ public final class Handle {
* {@link Opcodes#H_INVOKESPECIAL}, {@link Opcodes#H_NEWINVOKESPECIAL} or {@link
* Opcodes#H_INVOKEINTERFACE}.
* @param owner the internal name of the class that owns the field or method designated by this
- * handle.
+ * handle (see {@link Type#getInternalName()}).
* @param name the name of the field or method designated by this handle.
* @param descriptor the descriptor of the field or method designated by this handle.
* @param isInterface whether the owner is an interface or not.
@@ -118,7 +118,8 @@ public final class Handle {
/**
* Returns the internal name of the class that owns the field or method designated by this handle.
*
- * @return the internal name of the class that owns the field or method designated by this handle.
+ * @return the internal name of the class that owns the field or method designated by this handle
+ * (see {@link Type#getInternalName()}).
*/
public String getOwner() {
return owner;
diff --git a/asm/src/main/java/org/objectweb/asm/MethodTooLargeException.java b/asm/src/main/java/org/objectweb/asm/MethodTooLargeException.java
index 0097e39f..2fbf23b0 100644
--- a/asm/src/main/java/org/objectweb/asm/MethodTooLargeException.java
+++ b/asm/src/main/java/org/objectweb/asm/MethodTooLargeException.java
@@ -44,7 +44,7 @@ public final class MethodTooLargeException extends IndexOutOfBoundsException {
/**
* Constructs a new {@link MethodTooLargeException}.
*
- * @param className the internal name of the owner class.
+ * @param className the internal name of the owner class (see {@link Type#getInternalName()}).
* @param methodName the name of the method.
* @param descriptor the descriptor of the method.
* @param codeSize the size of the method's Code attribute, in bytes.
@@ -64,7 +64,7 @@ public final class MethodTooLargeException extends IndexOutOfBoundsException {
/**
* Returns the internal name of the owner class.
*
- * @return the internal name of the owner class.
+ * @return the internal name of the owner class (see {@link Type#getInternalName()}).
*/
public String getClassName() {
return className;
diff --git a/asm/src/main/java/org/objectweb/asm/MethodVisitor.java b/asm/src/main/java/org/objectweb/asm/MethodVisitor.java
index 92068e86..a5365a21 100644
--- a/asm/src/main/java/org/objectweb/asm/MethodVisitor.java
+++ b/asm/src/main/java/org/objectweb/asm/MethodVisitor.java
@@ -281,9 +281,9 @@ public abstract class MethodVisitor {
* types are represented by {@link Opcodes#TOP}, {@link Opcodes#INTEGER}, {@link
* Opcodes#FLOAT}, {@link Opcodes#LONG}, {@link Opcodes#DOUBLE}, {@link Opcodes#NULL} or
* {@link Opcodes#UNINITIALIZED_THIS} (long and double are represented by a single element).
- * Reference types are represented by String objects (representing internal names), and
- * uninitialized types by Label objects (this label designates the NEW instruction that
- * created this uninitialized value).
+ * Reference types are represented by String objects (representing internal names, see {@link
+ * Type#getInternalName()}), and uninitialized types by Label objects (this label designates
+ * the NEW instruction that created this uninitialized value).
* @param numStack the number of operand stack elements in the visited frame. Long and double
* values count for one stack element.
* @param stack the operand stack types in this frame. This array must not be modified. Its
@@ -364,7 +364,7 @@ public abstract class MethodVisitor {
/**
* Visits a type instruction. A type instruction is an instruction that takes the internal name of
- * a class as parameter.
+ * a class as parameter (see {@link Type#getInternalName()}).
*
* @param opcode the opcode of the type instruction to be visited. This opcode is either NEW,
* ANEWARRAY, CHECKCAST or INSTANCEOF.
@@ -647,8 +647,9 @@ public abstract class MethodVisitor {
* @param start the beginning of the exception handler's scope (inclusive).
* @param end the end of the exception handler's scope (exclusive).
* @param handler the beginning of the exception handler's code.
- * @param type the internal name of the type of exceptions handled by the handler, or {@literal
- * null} to catch any exceptions (for "finally" blocks).
+ * @param type the internal name of the type of exceptions handled by the handler (see {@link
+ * Type#getInternalName()}), or {@literal null} to catch any exceptions (for "finally"
+ * blocks).
* @throws IllegalArgumentException if one of the labels has already been visited by this visitor
* (by the {@link #visitLabel} method).
*/
diff --git a/asm/src/main/java/org/objectweb/asm/ModuleVisitor.java b/asm/src/main/java/org/objectweb/asm/ModuleVisitor.java
index 6ef58e71..70496fb1 100644
--- a/asm/src/main/java/org/objectweb/asm/ModuleVisitor.java
+++ b/asm/src/main/java/org/objectweb/asm/ModuleVisitor.java
@@ -85,7 +85,8 @@ public abstract class ModuleVisitor {
/**
* Visit the main class of the current module.
*
- * @param mainClass the internal name of the main class of the current module.
+ * @param mainClass the internal name of the main class of the current module (see {@link
+ * Type#getInternalName()}).
*/
public void visitMainClass(final String mainClass) {
if (mv != null) {
@@ -96,7 +97,7 @@ public abstract class ModuleVisitor {
/**
* Visit a package of the current module.
*
- * @param packaze the internal name of a package.
+ * @param packaze the internal name of a package (see {@link Type#getInternalName()}).
*/
public void visitPackage(final String packaze) {
if (mv != null) {
@@ -121,7 +122,7 @@ public abstract class ModuleVisitor {
/**
* Visit an exported package of the current module.
*
- * @param packaze the internal name of the exported package.
+ * @param packaze the internal name of the exported package (see {@link Type#getInternalName()}).
* @param access the access flag of the exported package, valid values are among {@code
* ACC_SYNTHETIC} and {@code ACC_MANDATED}.
* @param modules the fully qualified names (using dots) of the modules that can access the public
@@ -136,7 +137,7 @@ public abstract class ModuleVisitor {
/**
* Visit an open package of the current module.
*
- * @param packaze the internal name of the opened package.
+ * @param packaze the internal name of the opened package (see {@link Type#getInternalName()}).
* @param access the access flag of the opened package, valid values are among {@code
* ACC_SYNTHETIC} and {@code ACC_MANDATED}.
* @param modules the fully qualified names (using dots) of the modules that can use deep
@@ -152,7 +153,7 @@ public abstract class ModuleVisitor {
* Visit a service used by the current module. The name must be the internal name of an interface
* or a class.
*
- * @param service the internal name of the service.
+ * @param service the internal name of the service (see {@link Type#getInternalName()}).
*/
public void visitUse(final String service) {
if (mv != null) {
@@ -163,9 +164,9 @@ public abstract class ModuleVisitor {
/**
* Visit an implementation of a service.
*
- * @param service the internal name of the service.
- * @param providers the internal names of the implementations of the service (there is at least
- * one provider).
+ * @param service the internal name of the service (see {@link Type#getInternalName()}).
+ * @param providers the internal names (see {@link Type#getInternalName()}) of the implementations
+ * of the service (there is at least one provider).
*/
public void visitProvide(final String service, final String... providers) {
if (mv != null) {
diff --git a/asm/src/main/java/org/objectweb/asm/Type.java b/asm/src/main/java/org/objectweb/asm/Type.java
index 85a43547..85aab7ea 100644
--- a/asm/src/main/java/org/objectweb/asm/Type.java
+++ b/asm/src/main/java/org/objectweb/asm/Type.java
@@ -245,7 +245,7 @@ public final class Type {
/**
* Returns the {@link Type} corresponding to the given internal name.
*
- * @param internalName an internal name.
+ * @param internalName an internal name (see {@link Type#getInternalName()}).
* @return the {@link Type} corresponding to the given internal name.
*/
public static Type getObjectType(final String internalName) {
diff --git a/asm/src/main/java/org/objectweb/asm/signature/SignatureVisitor.java b/asm/src/main/java/org/objectweb/asm/signature/SignatureVisitor.java
index 500c8aef..b34df1d6 100644
--- a/asm/src/main/java/org/objectweb/asm/signature/SignatureVisitor.java
+++ b/asm/src/main/java/org/objectweb/asm/signature/SignatureVisitor.java
@@ -180,7 +180,8 @@ public abstract class SignatureVisitor {
/**
* Starts the visit of a signature corresponding to a class or interface type.
*
- * @param name the internal name of the class or interface.
+ * @param name the internal name of the class or interface (see {@link
+ * org.objectweb.asm.Type#getInternalName()}).
*/
public void visitClassType(final String name) {}
diff --git a/asm-util/src/main/java/org/objectweb/asm/util/Textifier.java b/asm-util/src/main/java/org/objectweb/asm/util/Textifier.java
index 4fd554c3..0049d357 100644
--- a/asm-util/src/main/java/org/objectweb/asm/util/Textifier.java
+++ b/asm-util/src/main/java/org/objectweb/asm/util/Textifier.java
@@ -55,7 +55,9 @@ public class Textifier extends Printer {
"Prints a disassembled view of the given class.\n"
+ "Usage: Textifier [-nodebug] <fully qualified class name or class file name>";
- /** The type of internal names. See {@link #appendDescriptor}. */
+ /**
+ * The type of internal names (see {@link Type#getInternalName()}). See {@link #appendDescriptor}.
+ */
public static final int INTERNAL_NAME = 0;
/** The type of field descriptors. See {@link #appendDescriptor}. */
@@ -1323,7 +1325,8 @@ public class Textifier extends Printer {
* @param type the type of 'value'. Must be one of {@link #INTERNAL_NAME}, {@link
* #FIELD_DESCRIPTOR}, {@link #FIELD_SIGNATURE}, {@link #METHOD_DESCRIPTOR}, {@link
* #METHOD_SIGNATURE}, {@link #CLASS_SIGNATURE} or {@link #HANDLE_DESCRIPTOR}.
- * @param value an internal name, type descriptor or a type signature. May be {@literal null}.
+ * @param value an internal name (see {@link Type#getInternalName()}), type descriptor or a type
+ * signature. May be {@literal null}.
*/
protected void appendDescriptor(final int type, final String value) {
if (type == CLASS_SIGNATURE || type == FIELD_SIGNATURE || type == METHOD_SIGNATURE) {